# Generated by Django 3.1.4 on 2021-01-03 23:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("killtracker", "0001_squashed_all"),
    ]

    operations = [
        migrations.AlterField(
            model_name="webhook",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="you can add notes about this webhook here if you want",
            ),
        ),
    ]
