 {% extends 'admin/base_site.html' %}

 {% block content %}
 <form action="" method="post">
    {% csrf_token %}
    <input type="hidden" name="action" value="run_test_killmail" />
    {{ form }}
    {% for tracker in queryset %}
        <input type="hidden" name="_selected_action" value="{{ tracker.pk }}" />
    {% endfor %}
    <br>
    <br>
    <input type="submit" name="apply" value="Load" />
    <a href="./"><input type="button" name="Cancel" value="Cancel"></a>
 </form>
 {% endblock %}
